# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/post/post.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2
from common.api.services.discussion import discussion_pb2 as services_dot_discussion_dot_discussion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18services/post/post.proto\x12\x0bsocial.post\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\x1a$services/discussion/discussion.proto\">\n\tRelatedTo\x12%\n\x03typ\x18\x01 \x01(\x0e\x32\x18.social.post.RelatedType\x12\n\n\x02to\x18\x02 \x01(\t\"\xbb\x03\n\x04Post\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x02 \x01(\t\x12)\n\x08location\x18\x03 \x01(\x0b\x32\x17.social.common.Location\x12(\n\x07\x61\x63\x63ount\x18\x04 \x01(\x0b\x32\x17.social.account.Account\x12\x14\n\x0cpublished_at\x18\x05 \x01(\x03\x12\x13\n\x0b\x61rchived_at\x18\x06 \x01(\x03\x12\x12\n\ndeleted_at\x18\x07 \x01(\x03\x12\x1b\n\x13is_disabled_comment\x18\x08 \x01(\x08\x12\x18\n\x10is_disabled_stat\x18\t \x01(\x08\x12#\n\x04stat\x18\n \x01(\x0b\x32\x15.social.post.PostStat\x12(\n\nmedia_list\x18\x0b \x03(\x0b\x32\x14.social.common.Media\x12\x10\n\x08is_liked\x18\x0c \x01(\x08\x12\x10\n\x08is_saved\x18\r \x01(\x08\x12,\n\x10preview_comments\x18\x0e \x03(\x0b\x32\x12.social.Discussion\x12*\n\nrelated_to\x18\x0f \x01(\x0b\x32\x16.social.post.RelatedTo\"I\n\x08PostStat\x12\x12\n\nlike_count\x18\x01 \x01(\x03\x12\x12\n\nview_count\x18\x02 \x01(\x03\x12\x15\n\rcomment_count\x18\x03 \x01(\x03\"4\n\x10PostListResponse\x12 \n\x05items\x18\x01 \x03(\x0b\x32\x11.social.post.Post\"^\n\x0fGetPostsRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x18\n\x10\x61\x63\x63ount_username\x18\x05 \x01(\t\"E\n\x14GetSavedPostsRequest\x12\x0e\n\x06\x63\x61t_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"B\n\x0fSavePostRequest\x12\x0e\n\x06\x63\x61t_id\x18\x01 \x01(\t\x12\x1f\n\x04post\x18\x02 \x01(\x0b\x32\x11.social.post.Post\"=\n\x0bLikeRequest\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\r\n\x05\x61\x63tor\x18\x03 \x01(\t\"U\n\x19GetPostsByLocationRequest\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0c\n\x04long\x18\x02 \x01(\x01\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\",\n\nTogglePost\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"7\n\x17InstagramCrawlerRequest\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\">\n\x18InstagramCrawlerResponse\x12\x12\n\nnext_field\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\t*8\n\x0bRelatedType\x12\x0b\n\x07TO_POST\x10\x00\x12\x0e\n\nTO_PRODUCT\x10\x01\x12\x0c\n\x08TO_STYLE\x10\x02\x32\xe3\x0c\n\x0bPostService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12X\n\x0fUploadPostMedia\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12\x33\n\x0bPublishPost\x12\x11.social.post.Post\x1a\x11.social.post.Post\x12\x32\n\nUpdatePost\x12\x11.social.post.Post\x1a\x11.social.post.Post\x12\x35\n\nDeletePost\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12/\n\x07GetPost\x12\x11.social.post.Post\x1a\x11.social.post.Post\x12G\n\x08GetPosts\x12\x1c.social.post.GetPostsRequest\x1a\x1d.social.post.PostListResponse\x12\x46\n\x07GetFeed\x12\x1c.social.post.GetPostsRequest\x1a\x1d.social.post.PostListResponse\x12\x41\n\x04\x46ind\x12\x1a.social.common.FindRequest\x1a\x1d.social.post.PostListResponse\x12Q\n\rGetSavedPosts\x12!.social.post.GetSavedPostsRequest\x1a\x1d.social.post.PostListResponse\x12>\n\x08SavePost\x12\x1c.social.post.SavePostRequest\x1a\x14.social.common.Empty\x12@\n\nUnSavePost\x12\x1c.social.post.SavePostRequest\x1a\x14.social.common.Empty\x12L\n\x10GetArchivedPosts\x12\x19.social.common.Pagination\x1a\x1d.social.post.PostListResponse\x12\x36\n\x0b\x41rchivePost\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12\x39\n\x0eUnArchivedPost\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12I\n\x0cGetPostsCats\x12\x19.social.common.Pagination\x1a\x1e.social.common.CatListResponse\x12\x41\n\rCreateSaveCat\x12\x17.social.common.Category\x1a\x17.social.common.Category\x12>\n\rDeleteSaveCat\x12\x17.social.common.Category\x1a\x14.social.common.Empty\x12[\n\x12GetPostsByLocation\x12&.social.post.GetPostsByLocationRequest\x1a\x1d.social.post.PostListResponse\x12\x36\n\x04Like\x12\x18.social.post.LikeRequest\x1a\x14.social.common.Empty\x12\x41\n\x10\x41\x64minPostArchive\x12\x17.social.post.TogglePost\x1a\x14.social.common.Empty\x12@\n\x0f\x41\x64minPostDelete\x12\x17.social.post.TogglePost\x1a\x14.social.common.Empty\x12:\n\x0f\x41\x64minPostUpdate\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12h\n\x15\x41\x64minInstagramCrawler\x12$.social.post.InstagramCrawlerRequest\x1a%.social.post.InstagramCrawlerResponse(\x01\x30\x01\x62\x06proto3')

_RELATEDTYPE = DESCRIPTOR.enum_types_by_name['RelatedType']
RelatedType = enum_type_wrapper.EnumTypeWrapper(_RELATEDTYPE)
TO_POST = 0
TO_PRODUCT = 1
TO_STYLE = 2


_RELATEDTO = DESCRIPTOR.message_types_by_name['RelatedTo']
_POST = DESCRIPTOR.message_types_by_name['Post']
_POSTSTAT = DESCRIPTOR.message_types_by_name['PostStat']
_POSTLISTRESPONSE = DESCRIPTOR.message_types_by_name['PostListResponse']
_GETPOSTSREQUEST = DESCRIPTOR.message_types_by_name['GetPostsRequest']
_GETSAVEDPOSTSREQUEST = DESCRIPTOR.message_types_by_name['GetSavedPostsRequest']
_SAVEPOSTREQUEST = DESCRIPTOR.message_types_by_name['SavePostRequest']
_LIKEREQUEST = DESCRIPTOR.message_types_by_name['LikeRequest']
_GETPOSTSBYLOCATIONREQUEST = DESCRIPTOR.message_types_by_name['GetPostsByLocationRequest']
_TOGGLEPOST = DESCRIPTOR.message_types_by_name['TogglePost']
_INSTAGRAMCRAWLERREQUEST = DESCRIPTOR.message_types_by_name['InstagramCrawlerRequest']
_INSTAGRAMCRAWLERRESPONSE = DESCRIPTOR.message_types_by_name['InstagramCrawlerResponse']
RelatedTo = _reflection.GeneratedProtocolMessageType('RelatedTo', (_message.Message,), {
  'DESCRIPTOR' : _RELATEDTO,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.RelatedTo)
  })
_sym_db.RegisterMessage(RelatedTo)

Post = _reflection.GeneratedProtocolMessageType('Post', (_message.Message,), {
  'DESCRIPTOR' : _POST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.Post)
  })
_sym_db.RegisterMessage(Post)

PostStat = _reflection.GeneratedProtocolMessageType('PostStat', (_message.Message,), {
  'DESCRIPTOR' : _POSTSTAT,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.PostStat)
  })
_sym_db.RegisterMessage(PostStat)

PostListResponse = _reflection.GeneratedProtocolMessageType('PostListResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTLISTRESPONSE,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.PostListResponse)
  })
_sym_db.RegisterMessage(PostListResponse)

GetPostsRequest = _reflection.GeneratedProtocolMessageType('GetPostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTSREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.GetPostsRequest)
  })
_sym_db.RegisterMessage(GetPostsRequest)

GetSavedPostsRequest = _reflection.GeneratedProtocolMessageType('GetSavedPostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSAVEDPOSTSREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.GetSavedPostsRequest)
  })
_sym_db.RegisterMessage(GetSavedPostsRequest)

SavePostRequest = _reflection.GeneratedProtocolMessageType('SavePostRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEPOSTREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.SavePostRequest)
  })
_sym_db.RegisterMessage(SavePostRequest)

LikeRequest = _reflection.GeneratedProtocolMessageType('LikeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LIKEREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.LikeRequest)
  })
_sym_db.RegisterMessage(LikeRequest)

GetPostsByLocationRequest = _reflection.GeneratedProtocolMessageType('GetPostsByLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTSBYLOCATIONREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.GetPostsByLocationRequest)
  })
_sym_db.RegisterMessage(GetPostsByLocationRequest)

TogglePost = _reflection.GeneratedProtocolMessageType('TogglePost', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEPOST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.TogglePost)
  })
_sym_db.RegisterMessage(TogglePost)

InstagramCrawlerRequest = _reflection.GeneratedProtocolMessageType('InstagramCrawlerRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSTAGRAMCRAWLERREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.InstagramCrawlerRequest)
  })
_sym_db.RegisterMessage(InstagramCrawlerRequest)

InstagramCrawlerResponse = _reflection.GeneratedProtocolMessageType('InstagramCrawlerResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSTAGRAMCRAWLERRESPONSE,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.InstagramCrawlerResponse)
  })
_sym_db.RegisterMessage(InstagramCrawlerResponse)

_POSTSERVICE = DESCRIPTOR.services_by_name['PostService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RELATEDTYPE._serialized_start=1332
  _RELATEDTYPE._serialized_end=1388
  _RELATEDTO._serialized_start=141
  _RELATEDTO._serialized_end=203
  _POST._serialized_start=206
  _POST._serialized_end=649
  _POSTSTAT._serialized_start=651
  _POSTSTAT._serialized_end=724
  _POSTLISTRESPONSE._serialized_start=726
  _POSTLISTRESPONSE._serialized_end=778
  _GETPOSTSREQUEST._serialized_start=780
  _GETPOSTSREQUEST._serialized_end=874
  _GETSAVEDPOSTSREQUEST._serialized_start=876
  _GETSAVEDPOSTSREQUEST._serialized_end=945
  _SAVEPOSTREQUEST._serialized_start=947
  _SAVEPOSTREQUEST._serialized_end=1013
  _LIKEREQUEST._serialized_start=1015
  _LIKEREQUEST._serialized_end=1076
  _GETPOSTSBYLOCATIONREQUEST._serialized_start=1078
  _GETPOSTSBYLOCATIONREQUEST._serialized_end=1163
  _TOGGLEPOST._serialized_start=1165
  _TOGGLEPOST._serialized_end=1209
  _INSTAGRAMCRAWLERREQUEST._serialized_start=1211
  _INSTAGRAMCRAWLERREQUEST._serialized_end=1266
  _INSTAGRAMCRAWLERRESPONSE._serialized_start=1268
  _INSTAGRAMCRAWLERRESPONSE._serialized_end=1330
  _POSTSERVICE._serialized_start=1391
  _POSTSERVICE._serialized_end=3026
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/account/account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/account/account.proto\x12\x0esocial.account\x1a\x1cservices/common/common.proto\"\\\n\x18\x43\x61rtPublishStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x0epublish_status\x18\x02 \x01(\x0b\x32\x1c.social.common.PublishStatus\"\x97\x01\n\nCreditCard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\t\x12\r\n\x05shaba\x18\x03 \x01(\t\x12\x13\n\x0b\x63\x61rd_holder\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x34\n\x0epublish_status\x18\x06 \x01(\x0b\x32\x1c.social.common.PublishStatus\"C\n\x16\x43reditCardListResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.social.account.CreditCard\"N\n\x16\x41\x63\x63ountAddressReceiver\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\"\xa7\x02\n\x0e\x41\x63\x63ountAddress\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x15\n\rneighbourhood\x18\x06 \x01(\t\x12\x0e\n\x06plaque\x18\x07 \x01(\t\x12\x0c\n\x04unit\x18\x08 \x01(\t\x12\x38\n\x08receiver\x18\t \x01(\x0b\x32&.social.account.AccountAddressReceiver\x12\x13\n\x0bpostal_code\x18\n \x01(\t\x12\x0b\n\x03lat\x18\x0b \x01(\x01\x12\x0c\n\x04long\x18\x0c \x01(\x01\x12\x12\n\nis_default\x18\r \x01(\x08\"D\n\x13\x41\x64\x64ressListResponse\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x1e.social.account.AccountAddress\"\x17\n\x05phone\x12\x0e\n\x06number\x18\x01 \x01(\t\">\n\x13SyncContactsRequest\x12\'\n\x08\x63ontacts\x18\x01 \x03(\x0b\x32\x15.social.account.phone\"K\n\x14SetVisibilityRequest\x12\x33\n\nvisibility\x18\x01 \x01(\x0e\x32\x1f.social.account.VisibilityTypes\".\n\x0eSendOtpRequest\x12\r\n\x05phone\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"%\n\x0fSendOtpResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"8\n\x10VerifyOtpRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"s\n\x11VerifyOtpResponse\x12$\n\x05token\x18\x01 \x01(\x0b\x32\x15.social.account.Token\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"\xf1\x04\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nnetwork_id\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\r\n\x05phone\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x10\n\x08password\x18\x07 \x01(\t\x12+\n\x06gender\x18\x08 \x01(\x0e\x32\x1b.social.account.GenderTypes\x12\x0b\n\x03\x62io\x18\t \x01(\t\x12\x13\n\x0bwebsite_url\x18\n \x01(\t\x12\x12\n\navatar_url\x18\x0b \x01(\t\x12\x10\n\x08\x62irthday\x18\x0c \x01(\x03\x12\x12\n\ncreated_at\x18\r \x01(\x03\x12\x13\n\x0b\x64isabled_at\x18\x0e \x01(\x03\x12\x12\n\ndeleted_at\x18\x0f \x01(\x03\x12\x11\n\tbanned_at\x18\x10 \x01(\x03\x12\x33\n\nvisibility\x18\x11 \x01(\x0e\x32\x1f.social.account.VisibilityTypes\x12\x12\n\nis_blocker\x18\x12 \x01(\x08\x12\x13\n\x0bis_blocking\x18\x13 \x01(\x08\x12)\n\x04stat\x18\x14 \x01(\x0b\x32\x1b.social.account.AccountStat\x12\x13\n\x0bis_verified\x18\x15 \x01(\x08\x12\x35\n\x08\x62usiness\x18\x16 \x01(\x0b\x32#.social.account.BusinessInformation\x12\x32\n\x0cnotification\x18\x17 \x01(\x0b\x32\x1c.social.account.Notification\x12\x12\n\nhas_avatar\x18\x18 \x01(\x08\x12\x0c\n\x04role\x18\x19 \x01(\t\"X\n\x13\x42usinessInformation\x12\r\n\x05phone\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08\"v\n\x0cNotification\x12\n\n\x02on\x18\x01 \x01(\x08\x12\x0c\n\x04like\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ollow\x18\x03 \x01(\x05\x12\x15\n\raccept_follow\x18\x04 \x01(\x05\x12\x0f\n\x07\x63omment\x18\x05 \x01(\x05\x12\x14\n\x0c\x63omment_like\x18\x06 \x01(\x05\"5\n\x08\x41\x63\x63ounts\x12)\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x17.social.account.Account\"\x90\x01\n\x0b\x41\x63\x63ountStat\x12\x12\n\npost_count\x18\x01 \x01(\x03\x12\x16\n\x0e\x66ollower_count\x18\x02 \x01(\x03\x12\x17\n\x0f\x66ollowing_count\x18\x03 \x01(\x03\x12\x13\n\x0bis_follower\x18\x04 \x01(\x05\x12\x14\n\x0cis_following\x18\x05 \x01(\x05\x12\x11\n\thas_story\x18\x06 \x01(\x08\"G\n\x12\x41\x63\x63ountListRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"=\n\x13\x41\x63\x63ountListResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.account.Account\"4\n\x05Token\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"4\n\x13GetBlackListRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"<\n\x14RefreshTokenResponse\x12$\n\x05token\x18\x01 \x01(\x0b\x32\x15.social.account.Token\"S\n\x14GetFollowingResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.account.Account\x12\x13\n\x0bhas_hashtag\x18\x02 \x01(\x08\"(\n\x14\x43heckUsernameRequest\x12\x10\n\x08username\x18\x01 \x01(\t\")\n\nSMSRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05phone\x18\x02 \x01(\t\"\"\n\x0bSMSResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\"\xb0\x01\n\x07Session\x12\n\n\x02id\x18\n \x01(\t\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x02 \x01(\t\x12\x11\n\tfcm_token\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\x05\x12\x0f\n\x07\x61pp_ver\x18\x05 \x01(\t\x12\x0e\n\x06os_ver\x18\x06 \x01(\t\x12\x0e\n\x06locale\x18\x07 \x01(\t\x12\n\n\x02ip\x18\x08 \x01(\t\x12\x10\n\x08login_at\x18\t \x01(\x03\"=\n\x13SessionListResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.account.Session\"2\n\rToggleAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"{\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0bpermissions\x18\x04 \x03(\t\x12\x11\n\tis_active\x18\x05 \x01(\x08\x12\x1c\n\x14login_to_admin_panel\x18\x06 \x01(\x08\"7\n\x10RoleListResponse\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.social.account.Role\"8\n\x0eRolePermission\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x15\n\rpermission_id\x18\x02 \x03(\t\"8\n\x11\x41ssignRoleRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0f\n\x07role_id\x18\x02 \x01(\t\"X\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nclass_name\x18\x03 \x01(\t\x12\x15\n\rfunction_name\x18\x04 \x01(\t\"C\n\x16PermissionListResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.social.account.Permission\"D\n\x12RoleAccountRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"(\n\x12\x41\x63\x63ountRoleRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t*7\n\x0fVisibilityTypes\x12\n\n\x06PUBLIC\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\x0b\n\x07NETWORK\x10\x02*-\n\x0bGenderTypes\x12\x08\n\x04None\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02\x32\xfc\'\n\x0e\x41\x63\x63ountService\x12J\n\x07SendOtp\x12\x1e.social.account.SendOtpRequest\x1a\x1f.social.account.SendOtpResponse\x12P\n\tVerifyOtp\x12 .social.account.VerifyOtpRequest\x1a!.social.account.VerifyOtpResponse\x12\x46\n\x08Register\x12\x17.social.account.Account\x1a!.social.account.VerifyOtpResponse\x12\x34\n\x06LogOut\x12\x14.social.common.Empty\x1a\x14.social.common.Empty\x12>\n\nGetProfile\x12\x17.social.account.Account\x1a\x17.social.account.Account\x12\x41\n\x0bGetProfiles\x12\x18.social.account.Accounts\x1a\x18.social.account.Accounts\x12\x41\n\rUpdateProfile\x12\x17.social.account.Account\x1a\x17.social.account.Account\x12L\n\x16GetNotificationSetting\x12\x14.social.common.Empty\x1a\x1c.social.account.Notification\x12O\n\x19UpdateNotificationSetting\x12\x1c.social.account.Notification\x1a\x14.social.common.Empty\x12G\n\x04\x46ind\x12\x1a.social.common.FindRequest\x1a#.social.account.AccountListResponse\x12?\n\x06\x44\x65lete\x12\x14.social.common.Empty\x1a\x1f.social.account.SendOtpResponse\x12\x46\n\x0c\x44\x65leteVerify\x12 .social.account.VerifyOtpRequest\x1a\x14.social.common.Empty\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x37\n\x06\x46ollow\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x39\n\x08Unfollow\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x36\n\x05\x42lock\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x38\n\x07Unblock\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12X\n\x0cGetBlockList\x12#.social.account.GetBlackListRequest\x1a#.social.account.AccountListResponse\x12W\n\x0cGetFollowers\x12\".social.account.AccountListRequest\x1a#.social.account.AccountListResponse\x12X\n\x0cGetFollowing\x12\".social.account.AccountListRequest\x1a$.social.account.GetFollowingResponse\x12\\\n\x11GetFollowRequests\x12\".social.account.AccountListRequest\x1a#.social.account.AccountListResponse\x12Y\n\x0cRefreshToken\x12#.social.account.RefreshTokenRequest\x1a$.social.account.RefreshTokenResponse\x12N\n\x12UploadProfilePhoto\x12\x14.social.common.Empty\x1a\".social.common.UploadMediaResponse\x12\x44\n\x13\x41\x63\x63\x65ptFollowRequest\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x44\n\x13RejectFollowRequest\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12K\n\rSetVisibility\x12$.social.account.SetVisibilityRequest\x1a\x14.social.common.Empty\x12Z\n\x18GetPendingFollowRequests\x12\x19.social.common.Pagination\x1a#.social.account.AccountListResponse\x12\x43\n\x0bisFollowing\x12\x17.social.account.Account\x1a\x1b.social.common.BooleanValue\x12\x42\n\nisFollower\x12\x17.social.account.Account\x1a\x1b.social.common.BooleanValue\x12X\n\x13isUsernameAvailable\x12$.social.account.CheckUsernameRequest\x1a\x1b.social.common.BooleanValue\x12\x42\n\nisVerified\x12\x17.social.account.Account\x1a\x1b.social.common.BooleanValue\x12J\n\x19ToggleAccountVerification\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12?\n\x11ToggleAccountType\x12\x14.social.common.Empty\x1a\x14.social.common.Empty\x12=\n\x0cSetPushToken\x12\x17.social.account.Session\x1a\x14.social.common.Empty\x12I\n\x0cSyncContacts\x12#.social.account.SyncContactsRequest\x1a\x14.social.common.Empty\x12M\n\x0bSuggestions\x12\x19.social.common.Pagination\x1a#.social.account.AccountListResponse\x12\x42\n\nAddAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12\x45\n\rUpdateAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12\x45\n\rDeleteAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12Q\n\x0fGetAllAddresses\x12\x19.social.common.Pagination\x1a#.social.account.AddressListResponse\x12I\n\x11SetDefaultAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12\x41\n\rAddCreditCard\x12\x1a.social.account.CreditCard\x1a\x14.social.common.Empty\x12\x44\n\x10UpdateCreditCard\x12\x1a.social.account.CreditCard\x1a\x14.social.common.Empty\x12\x44\n\x10\x44\x65leteCreditCard\x12\x1a.social.account.CreditCard\x1a\x14.social.common.Empty\x12V\n\x11GetAllCreditCards\x12\x19.social.common.Pagination\x1a&.social.account.CreditCardListResponse\x12_\n\x1d\x41\x64minAccountApproveCreditCard\x12(.social.account.CartPublishStatusRequest\x1a\x14.social.common.Empty\x12^\n\x1c\x41\x64minAccountRejectCreditCard\x12(.social.account.CartPublishStatusRequest\x1a\x14.social.common.Empty\x12M\n\x0bGetSessions\x12\x19.social.common.Pagination\x1a#.social.account.SessionListResponse\x12G\n\x0fisSessionActive\x12\x17.social.account.Session\x1a\x1b.social.common.BooleanValue\x12>\n\rDeleteSession\x12\x17.social.account.Session\x1a\x14.social.common.Empty\x12J\n\x13\x41\x64minAccountDisable\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12I\n\x12\x41\x64minAccountDelete\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12I\n\x12\x41\x64minAccountVerify\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12\x46\n\x0f\x41\x64minAccountBan\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12\x46\n\x12\x41\x64minAccountUpdate\x12\x17.social.account.Account\x1a\x17.social.account.Account\x12Q\n\x0f\x41\x64minAccountAll\x12\x19.social.common.Pagination\x1a#.social.account.AccountListResponse\x12O\n\x0c\x41\x64minSendOTP\x12\x1e.social.account.SendOtpRequest\x1a\x1f.social.account.SendOtpResponse\x12<\n\x0eRootCreateRole\x12\x14.social.account.Role\x1a\x14.social.account.Role\x12<\n\x0eRootUpdateRole\x12\x14.social.account.Role\x1a\x14.social.common.Empty\x12<\n\x0eRootDeleteRole\x12\x14.social.account.Role\x1a\x14.social.common.Empty\x12N\n\x0fRootGetAllRoles\x12\x19.social.common.Pagination\x1a .social.account.RoleListResponse\x12O\n\x17RootAddPermissionToRole\x12\x1e.social.account.RolePermission\x1a\x14.social.common.Empty\x12T\n\x1cRootRemovePermissionFromRole\x12\x1e.social.account.RolePermission\x1a\x14.social.common.Empty\x12I\n\x0eRootAssignRole\x12!.social.account.AssignRoleRequest\x1a\x14.social.common.Empty\x12K\n\x10RootUnassignRole\x12!.social.account.AssignRoleRequest\x1a\x14.social.common.Empty\x12U\n\x15RootGetAllPermissions\x12\x14.social.common.Empty\x1a&.social.account.PermissionListResponse\x12\x63\n\x18RootGetAllAccountsInRole\x12\".social.account.RoleAccountRequest\x1a#.social.account.AccountListResponse\x12[\n\x13RootGetAccountRoles\x12\".social.account.AccountRoleRequest\x1a .social.account.RoleListResponseb\x06proto3')

_VISIBILITYTYPES = DESCRIPTOR.enum_types_by_name['VisibilityTypes']
VisibilityTypes = enum_type_wrapper.EnumTypeWrapper(_VISIBILITYTYPES)
_GENDERTYPES = DESCRIPTOR.enum_types_by_name['GenderTypes']
GenderTypes = enum_type_wrapper.EnumTypeWrapper(_GENDERTYPES)
PUBLIC = 0
PRIVATE = 1
NETWORK = 2
globals()['None'] = 0
MALE = 1
FEMALE = 2


_CARTPUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['CartPublishStatusRequest']
_CREDITCARD = DESCRIPTOR.message_types_by_name['CreditCard']
_CREDITCARDLISTRESPONSE = DESCRIPTOR.message_types_by_name['CreditCardListResponse']
_ACCOUNTADDRESSRECEIVER = DESCRIPTOR.message_types_by_name['AccountAddressReceiver']
_ACCOUNTADDRESS = DESCRIPTOR.message_types_by_name['AccountAddress']
_ADDRESSLISTRESPONSE = DESCRIPTOR.message_types_by_name['AddressListResponse']
_PHONE = DESCRIPTOR.message_types_by_name['phone']
_SYNCCONTACTSREQUEST = DESCRIPTOR.message_types_by_name['SyncContactsRequest']
_SETVISIBILITYREQUEST = DESCRIPTOR.message_types_by_name['SetVisibilityRequest']
_SENDOTPREQUEST = DESCRIPTOR.message_types_by_name['SendOtpRequest']
_SENDOTPRESPONSE = DESCRIPTOR.message_types_by_name['SendOtpResponse']
_VERIFYOTPREQUEST = DESCRIPTOR.message_types_by_name['VerifyOtpRequest']
_VERIFYOTPRESPONSE = DESCRIPTOR.message_types_by_name['VerifyOtpResponse']
_ACCOUNT = DESCRIPTOR.message_types_by_name['Account']
_BUSINESSINFORMATION = DESCRIPTOR.message_types_by_name['BusinessInformation']
_NOTIFICATION = DESCRIPTOR.message_types_by_name['Notification']
_ACCOUNTS = DESCRIPTOR.message_types_by_name['Accounts']
_ACCOUNTSTAT = DESCRIPTOR.message_types_by_name['AccountStat']
_ACCOUNTLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountListRequest']
_ACCOUNTLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountListResponse']
_TOKEN = DESCRIPTOR.message_types_by_name['Token']
_GETBLACKLISTREQUEST = DESCRIPTOR.message_types_by_name['GetBlackListRequest']
_REFRESHTOKENREQUEST = DESCRIPTOR.message_types_by_name['RefreshTokenRequest']
_REFRESHTOKENRESPONSE = DESCRIPTOR.message_types_by_name['RefreshTokenResponse']
_GETFOLLOWINGRESPONSE = DESCRIPTOR.message_types_by_name['GetFollowingResponse']
_CHECKUSERNAMEREQUEST = DESCRIPTOR.message_types_by_name['CheckUsernameRequest']
_SMSREQUEST = DESCRIPTOR.message_types_by_name['SMSRequest']
_SMSRESPONSE = DESCRIPTOR.message_types_by_name['SMSResponse']
_SESSION = DESCRIPTOR.message_types_by_name['Session']
_SESSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['SessionListResponse']
_TOGGLEACCOUNT = DESCRIPTOR.message_types_by_name['ToggleAccount']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
_ROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['RoleListResponse']
_ROLEPERMISSION = DESCRIPTOR.message_types_by_name['RolePermission']
_ASSIGNROLEREQUEST = DESCRIPTOR.message_types_by_name['AssignRoleRequest']
_PERMISSION = DESCRIPTOR.message_types_by_name['Permission']
_PERMISSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['PermissionListResponse']
_ROLEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['RoleAccountRequest']
_ACCOUNTROLEREQUEST = DESCRIPTOR.message_types_by_name['AccountRoleRequest']
CartPublishStatusRequest = _reflection.GeneratedProtocolMessageType('CartPublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CARTPUBLISHSTATUSREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CartPublishStatusRequest)
  })
_sym_db.RegisterMessage(CartPublishStatusRequest)

CreditCard = _reflection.GeneratedProtocolMessageType('CreditCard', (_message.Message,), {
  'DESCRIPTOR' : _CREDITCARD,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CreditCard)
  })
_sym_db.RegisterMessage(CreditCard)

CreditCardListResponse = _reflection.GeneratedProtocolMessageType('CreditCardListResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREDITCARDLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CreditCardListResponse)
  })
_sym_db.RegisterMessage(CreditCardListResponse)

AccountAddressReceiver = _reflection.GeneratedProtocolMessageType('AccountAddressReceiver', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTADDRESSRECEIVER,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountAddressReceiver)
  })
_sym_db.RegisterMessage(AccountAddressReceiver)

AccountAddress = _reflection.GeneratedProtocolMessageType('AccountAddress', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTADDRESS,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountAddress)
  })
_sym_db.RegisterMessage(AccountAddress)

AddressListResponse = _reflection.GeneratedProtocolMessageType('AddressListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AddressListResponse)
  })
_sym_db.RegisterMessage(AddressListResponse)

phone = _reflection.GeneratedProtocolMessageType('phone', (_message.Message,), {
  'DESCRIPTOR' : _PHONE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.phone)
  })
_sym_db.RegisterMessage(phone)

SyncContactsRequest = _reflection.GeneratedProtocolMessageType('SyncContactsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCCONTACTSREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SyncContactsRequest)
  })
_sym_db.RegisterMessage(SyncContactsRequest)

SetVisibilityRequest = _reflection.GeneratedProtocolMessageType('SetVisibilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVISIBILITYREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SetVisibilityRequest)
  })
_sym_db.RegisterMessage(SetVisibilityRequest)

SendOtpRequest = _reflection.GeneratedProtocolMessageType('SendOtpRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDOTPREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SendOtpRequest)
  })
_sym_db.RegisterMessage(SendOtpRequest)

SendOtpResponse = _reflection.GeneratedProtocolMessageType('SendOtpResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDOTPRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SendOtpResponse)
  })
_sym_db.RegisterMessage(SendOtpResponse)

VerifyOtpRequest = _reflection.GeneratedProtocolMessageType('VerifyOtpRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYOTPREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.VerifyOtpRequest)
  })
_sym_db.RegisterMessage(VerifyOtpRequest)

VerifyOtpResponse = _reflection.GeneratedProtocolMessageType('VerifyOtpResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYOTPRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.VerifyOtpResponse)
  })
_sym_db.RegisterMessage(VerifyOtpResponse)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Account)
  })
_sym_db.RegisterMessage(Account)

BusinessInformation = _reflection.GeneratedProtocolMessageType('BusinessInformation', (_message.Message,), {
  'DESCRIPTOR' : _BUSINESSINFORMATION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.BusinessInformation)
  })
_sym_db.RegisterMessage(BusinessInformation)

Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Notification)
  })
_sym_db.RegisterMessage(Notification)

Accounts = _reflection.GeneratedProtocolMessageType('Accounts', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTS,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Accounts)
  })
_sym_db.RegisterMessage(Accounts)

AccountStat = _reflection.GeneratedProtocolMessageType('AccountStat', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSTAT,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountStat)
  })
_sym_db.RegisterMessage(AccountStat)

AccountListRequest = _reflection.GeneratedProtocolMessageType('AccountListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLISTREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountListRequest)
  })
_sym_db.RegisterMessage(AccountListRequest)

AccountListResponse = _reflection.GeneratedProtocolMessageType('AccountListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountListResponse)
  })
_sym_db.RegisterMessage(AccountListResponse)

Token = _reflection.GeneratedProtocolMessageType('Token', (_message.Message,), {
  'DESCRIPTOR' : _TOKEN,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Token)
  })
_sym_db.RegisterMessage(Token)

GetBlackListRequest = _reflection.GeneratedProtocolMessageType('GetBlackListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLACKLISTREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.GetBlackListRequest)
  })
_sym_db.RegisterMessage(GetBlackListRequest)

RefreshTokenRequest = _reflection.GeneratedProtocolMessageType('RefreshTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RefreshTokenRequest)
  })
_sym_db.RegisterMessage(RefreshTokenRequest)

RefreshTokenResponse = _reflection.GeneratedProtocolMessageType('RefreshTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RefreshTokenResponse)
  })
_sym_db.RegisterMessage(RefreshTokenResponse)

GetFollowingResponse = _reflection.GeneratedProtocolMessageType('GetFollowingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFOLLOWINGRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.GetFollowingResponse)
  })
_sym_db.RegisterMessage(GetFollowingResponse)

CheckUsernameRequest = _reflection.GeneratedProtocolMessageType('CheckUsernameRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKUSERNAMEREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CheckUsernameRequest)
  })
_sym_db.RegisterMessage(CheckUsernameRequest)

SMSRequest = _reflection.GeneratedProtocolMessageType('SMSRequest', (_message.Message,), {
  'DESCRIPTOR' : _SMSREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SMSRequest)
  })
_sym_db.RegisterMessage(SMSRequest)

SMSResponse = _reflection.GeneratedProtocolMessageType('SMSResponse', (_message.Message,), {
  'DESCRIPTOR' : _SMSRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SMSResponse)
  })
_sym_db.RegisterMessage(SMSResponse)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Session)
  })
_sym_db.RegisterMessage(Session)

SessionListResponse = _reflection.GeneratedProtocolMessageType('SessionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SessionListResponse)
  })
_sym_db.RegisterMessage(SessionListResponse)

ToggleAccount = _reflection.GeneratedProtocolMessageType('ToggleAccount', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEACCOUNT,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.ToggleAccount)
  })
_sym_db.RegisterMessage(ToggleAccount)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Role)
  })
_sym_db.RegisterMessage(Role)

RoleListResponse = _reflection.GeneratedProtocolMessageType('RoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLELISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RoleListResponse)
  })
_sym_db.RegisterMessage(RoleListResponse)

RolePermission = _reflection.GeneratedProtocolMessageType('RolePermission', (_message.Message,), {
  'DESCRIPTOR' : _ROLEPERMISSION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RolePermission)
  })
_sym_db.RegisterMessage(RolePermission)

AssignRoleRequest = _reflection.GeneratedProtocolMessageType('AssignRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSIGNROLEREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AssignRoleRequest)
  })
_sym_db.RegisterMessage(AssignRoleRequest)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Permission)
  })
_sym_db.RegisterMessage(Permission)

PermissionListResponse = _reflection.GeneratedProtocolMessageType('PermissionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.PermissionListResponse)
  })
_sym_db.RegisterMessage(PermissionListResponse)

RoleAccountRequest = _reflection.GeneratedProtocolMessageType('RoleAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEACCOUNTREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RoleAccountRequest)
  })
_sym_db.RegisterMessage(RoleAccountRequest)

AccountRoleRequest = _reflection.GeneratedProtocolMessageType('AccountRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTROLEREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountRoleRequest)
  })
_sym_db.RegisterMessage(AccountRoleRequest)

_ACCOUNTSERVICE = DESCRIPTOR.services_by_name['AccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VISIBILITYTYPES._serialized_start=3734
  _VISIBILITYTYPES._serialized_end=3789
  _GENDERTYPES._serialized_start=3791
  _GENDERTYPES._serialized_end=3836
  _CARTPUBLISHSTATUSREQUEST._serialized_start=80
  _CARTPUBLISHSTATUSREQUEST._serialized_end=172
  _CREDITCARD._serialized_start=175
  _CREDITCARD._serialized_end=326
  _CREDITCARDLISTRESPONSE._serialized_start=328
  _CREDITCARDLISTRESPONSE._serialized_end=395
  _ACCOUNTADDRESSRECEIVER._serialized_start=397
  _ACCOUNTADDRESSRECEIVER._serialized_end=475
  _ACCOUNTADDRESS._serialized_start=478
  _ACCOUNTADDRESS._serialized_end=773
  _ADDRESSLISTRESPONSE._serialized_start=775
  _ADDRESSLISTRESPONSE._serialized_end=843
  _PHONE._serialized_start=845
  _PHONE._serialized_end=868
  _SYNCCONTACTSREQUEST._serialized_start=870
  _SYNCCONTACTSREQUEST._serialized_end=932
  _SETVISIBILITYREQUEST._serialized_start=934
  _SETVISIBILITYREQUEST._serialized_end=1009
  _SENDOTPREQUEST._serialized_start=1011
  _SENDOTPREQUEST._serialized_end=1057
  _SENDOTPRESPONSE._serialized_start=1059
  _SENDOTPRESPONSE._serialized_end=1096
  _VERIFYOTPREQUEST._serialized_start=1098
  _VERIFYOTPREQUEST._serialized_end=1154
  _VERIFYOTPRESPONSE._serialized_start=1156
  _VERIFYOTPRESPONSE._serialized_end=1271
  _ACCOUNT._serialized_start=1274
  _ACCOUNT._serialized_end=1899
  _BUSINESSINFORMATION._serialized_start=1901
  _BUSINESSINFORMATION._serialized_end=1989
  _NOTIFICATION._serialized_start=1991
  _NOTIFICATION._serialized_end=2109
  _ACCOUNTS._serialized_start=2111
  _ACCOUNTS._serialized_end=2164
  _ACCOUNTSTAT._serialized_start=2167
  _ACCOUNTSTAT._serialized_end=2311
  _ACCOUNTLISTREQUEST._serialized_start=2313
  _ACCOUNTLISTREQUEST._serialized_end=2384
  _ACCOUNTLISTRESPONSE._serialized_start=2386
  _ACCOUNTLISTRESPONSE._serialized_end=2447
  _TOKEN._serialized_start=2449
  _TOKEN._serialized_end=2501
  _GETBLACKLISTREQUEST._serialized_start=2503
  _GETBLACKLISTREQUEST._serialized_end=2555
  _REFRESHTOKENREQUEST._serialized_start=2557
  _REFRESHTOKENREQUEST._serialized_end=2601
  _REFRESHTOKENRESPONSE._serialized_start=2603
  _REFRESHTOKENRESPONSE._serialized_end=2663
  _GETFOLLOWINGRESPONSE._serialized_start=2665
  _GETFOLLOWINGRESPONSE._serialized_end=2748
  _CHECKUSERNAMEREQUEST._serialized_start=2750
  _CHECKUSERNAMEREQUEST._serialized_end=2790
  _SMSREQUEST._serialized_start=2792
  _SMSREQUEST._serialized_end=2833
  _SMSRESPONSE._serialized_start=2835
  _SMSRESPONSE._serialized_end=2869
  _SESSION._serialized_start=2872
  _SESSION._serialized_end=3048
  _SESSIONLISTRESPONSE._serialized_start=3050
  _SESSIONLISTRESPONSE._serialized_end=3111
  _TOGGLEACCOUNT._serialized_start=3113
  _TOGGLEACCOUNT._serialized_end=3163
  _ROLE._serialized_start=3165
  _ROLE._serialized_end=3288
  _ROLELISTRESPONSE._serialized_start=3290
  _ROLELISTRESPONSE._serialized_end=3345
  _ROLEPERMISSION._serialized_start=3347
  _ROLEPERMISSION._serialized_end=3403
  _ASSIGNROLEREQUEST._serialized_start=3405
  _ASSIGNROLEREQUEST._serialized_end=3461
  _PERMISSION._serialized_start=3463
  _PERMISSION._serialized_end=3551
  _PERMISSIONLISTRESPONSE._serialized_start=3553
  _PERMISSIONLISTRESPONSE._serialized_end=3620
  _ROLEACCOUNTREQUEST._serialized_start=3622
  _ROLEACCOUNTREQUEST._serialized_end=3690
  _ACCOUNTROLEREQUEST._serialized_start=3692
  _ACCOUNTROLEREQUEST._serialized_end=3732
  _ACCOUNTSERVICE._serialized_start=3839
  _ACCOUNTSERVICE._serialized_end=8955
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.story import story_pb2 as services_dot_story_dot_story__pb2


class StoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/social.story.StoryService/Ping',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Pong.FromString,
                )
        self.UploadStoryMedia = channel.unary_unary(
                '/social.story.StoryService/UploadStoryMedia',
                request_serializer=services_dot_common_dot_common__pb2.UploadMediaRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.UploadMediaResponse.FromString,
                )
        self.PublishStory = channel.unary_unary(
                '/social.story.StoryService/PublishStory',
                request_serializer=services_dot_story_dot_story__pb2.Story.SerializeToString,
                response_deserializer=services_dot_story_dot_story__pb2.Story.FromString,
                )
        self.DeleteStory = channel.unary_unary(
                '/social.story.StoryService/DeleteStory',
                request_serializer=services_dot_story_dot_story__pb2.Story.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetStory = channel.unary_unary(
                '/social.story.StoryService/GetStory',
                request_serializer=services_dot_story_dot_story__pb2.Story.SerializeToString,
                response_deserializer=services_dot_story_dot_story__pb2.Story.FromString,
                )
        self.GetStories = channel.unary_unary(
                '/social.story.StoryService/GetStories',
                request_serializer=services_dot_story_dot_story__pb2.GetStoryRequest.SerializeToString,
                response_deserializer=services_dot_story_dot_story__pb2.StoryListResponse.FromString,
                )
        self.GetFeed = channel.unary_unary(
                '/social.story.StoryService/GetFeed',
                request_serializer=services_dot_story_dot_story__pb2.GetStoryFeedRequest.SerializeToString,
                response_deserializer=services_dot_story_dot_story__pb2.StoryFeedResponse.FromString,
                )
        self.GetArchives = channel.unary_unary(
                '/social.story.StoryService/GetArchives',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_story_dot_story__pb2.StoryListResponse.FromString,
                )
        self.AdminStoryDelete = channel.unary_unary(
                '/social.story.StoryService/AdminStoryDelete',
                request_serializer=services_dot_story_dot_story__pb2.ToggleStory.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )


class StoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadStoryMedia(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishStory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetArchives(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminStoryDelete(self, request, context):
        """Admin Section. All admin services starts with `AdminSERVICE_NAME`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Pong.SerializeToString,
            ),
            'UploadStoryMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadStoryMedia,
                    request_deserializer=services_dot_common_dot_common__pb2.UploadMediaRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.UploadMediaResponse.SerializeToString,
            ),
            'PublishStory': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishStory,
                    request_deserializer=services_dot_story_dot_story__pb2.Story.FromString,
                    response_serializer=services_dot_story_dot_story__pb2.Story.SerializeToString,
            ),
            'DeleteStory': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStory,
                    request_deserializer=services_dot_story_dot_story__pb2.Story.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetStory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStory,
                    request_deserializer=services_dot_story_dot_story__pb2.Story.FromString,
                    response_serializer=services_dot_story_dot_story__pb2.Story.SerializeToString,
            ),
            'GetStories': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStories,
                    request_deserializer=services_dot_story_dot_story__pb2.GetStoryRequest.FromString,
                    response_serializer=services_dot_story_dot_story__pb2.StoryListResponse.SerializeToString,
            ),
            'GetFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeed,
                    request_deserializer=services_dot_story_dot_story__pb2.GetStoryFeedRequest.FromString,
                    response_serializer=services_dot_story_dot_story__pb2.StoryFeedResponse.SerializeToString,
            ),
            'GetArchives': grpc.unary_unary_rpc_method_handler(
                    servicer.GetArchives,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_story_dot_story__pb2.StoryListResponse.SerializeToString,
            ),
            'AdminStoryDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminStoryDelete,
                    request_deserializer=services_dot_story_dot_story__pb2.ToggleStory.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'social.story.StoryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/Ping',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_common_dot_common__pb2.Pong.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadStoryMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/UploadStoryMedia',
            services_dot_common_dot_common__pb2.UploadMediaRequest.SerializeToString,
            services_dot_common_dot_common__pb2.UploadMediaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishStory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/PublishStory',
            services_dot_story_dot_story__pb2.Story.SerializeToString,
            services_dot_story_dot_story__pb2.Story.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/DeleteStory',
            services_dot_story_dot_story__pb2.Story.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/GetStory',
            services_dot_story_dot_story__pb2.Story.SerializeToString,
            services_dot_story_dot_story__pb2.Story.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/GetStories',
            services_dot_story_dot_story__pb2.GetStoryRequest.SerializeToString,
            services_dot_story_dot_story__pb2.StoryListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/GetFeed',
            services_dot_story_dot_story__pb2.GetStoryFeedRequest.SerializeToString,
            services_dot_story_dot_story__pb2.StoryFeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetArchives(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/GetArchives',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_story_dot_story__pb2.StoryListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminStoryDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.story.StoryService/AdminStoryDelete',
            services_dot_story_dot_story__pb2.ToggleStory.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.discussion import discussion_pb2 as services_dot_discussion_dot_discussion__pb2


class DiscussionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/social.DiscussionService/Ping',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Pong.FromString,
                )
        self.Publish = channel.unary_unary(
                '/social.DiscussionService/Publish',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                )
        self.Update = channel.unary_unary(
                '/social.DiscussionService/Update',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.Delete = channel.unary_unary(
                '/social.DiscussionService/Delete',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetDiscussions = channel.unary_unary(
                '/social.DiscussionService/GetDiscussions',
                request_serializer=services_dot_discussion_dot_discussion__pb2.GetDiscussionsRequest.SerializeToString,
                response_deserializer=services_dot_discussion_dot_discussion__pb2.DiscussionListResponse.FromString,
                )
        self.Like = channel.unary_unary(
                '/social.DiscussionService/Like',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.Dislike = channel.unary_unary(
                '/social.DiscussionService/Dislike',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.Pin = channel.unary_unary(
                '/social.DiscussionService/Pin',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.UnPin = channel.unary_unary(
                '/social.DiscussionService/UnPin',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminDiscussionDelete = channel.unary_unary(
                '/social.DiscussionService/AdminDiscussionDelete',
                request_serializer=services_dot_discussion_dot_discussion__pb2.ToggleDiscussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminDiscussionUpdate = channel.unary_unary(
                '/social.DiscussionService/AdminDiscussionUpdate',
                request_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )


class DiscussionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Publish(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDiscussions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Like(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Dislike(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnPin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminDiscussionDelete(self, request, context):
        """Admin Section. All admin services starts with `AdminSERVICE_NAME`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminDiscussionUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DiscussionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Pong.SerializeToString,
            ),
            'Publish': grpc.unary_unary_rpc_method_handler(
                    servicer.Publish,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetDiscussions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDiscussions,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.GetDiscussionsRequest.FromString,
                    response_serializer=services_dot_discussion_dot_discussion__pb2.DiscussionListResponse.SerializeToString,
            ),
            'Like': grpc.unary_unary_rpc_method_handler(
                    servicer.Like,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'Dislike': grpc.unary_unary_rpc_method_handler(
                    servicer.Dislike,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'Pin': grpc.unary_unary_rpc_method_handler(
                    servicer.Pin,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'UnPin': grpc.unary_unary_rpc_method_handler(
                    servicer.UnPin,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminDiscussionDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminDiscussionDelete,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.ToggleDiscussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminDiscussionUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminDiscussionUpdate,
                    request_deserializer=services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'social.DiscussionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DiscussionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Ping',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_common_dot_common__pb2.Pong.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Publish',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_discussion_dot_discussion__pb2.Discussion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Update',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Delete',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDiscussions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/GetDiscussions',
            services_dot_discussion_dot_discussion__pb2.GetDiscussionsRequest.SerializeToString,
            services_dot_discussion_dot_discussion__pb2.DiscussionListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Like(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Like',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Dislike(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Dislike',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/Pin',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnPin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/UnPin',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminDiscussionDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/AdminDiscussionDelete',
            services_dot_discussion_dot_discussion__pb2.ToggleDiscussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminDiscussionUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.DiscussionService/AdminDiscussionUpdate',
            services_dot_discussion_dot_discussion__pb2.Discussion.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/history/history.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/history/history.proto\x12\x0esocial.history\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\"\xb1\x01\n\x03\x41\x63t\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.social.history.ActTypes\x12\x0b\n\x03obj\x18\x03 \x01(\t\x12\r\n\x05obj_o\x18\x04 \x01(\t\x12&\n\x05\x61\x63tor\x18\x05 \x01(\x0b\x32\x17.social.account.Account\x12&\n\x04verb\x18\x06 \x01(\x0e\x32\x18.social.history.ActVerbs\x12\n\n\x02\x61t\x18\x07 \x01(\x03\"5\n\x14GetActivitiesRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\"5\n\x0f\x41\x63tListResponse\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.social.history.Act*I\n\x08\x41\x63tTypes\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x00\x12\x08\n\x04POST\x10\x01\x12\t\n\x05STORY\x10\x02\x12\x0e\n\nDISCUSSION\x10\x03\x12\x0b\n\x07HASHTAG\x10\x04*\xfa\x01\n\x08\x41\x63tVerbs\x12\x08\n\x04LIKE\x10\x00\x12\n\n\x06UNLIKE\x10\x01\x12\n\n\x06\x46OLLOW\x10\x02\x12\x0c\n\x08UNFOLLOW\x10\x03\x12\x12\n\x0e\x46OLLOW_REQUEST\x10\x04\x12\x07\n\x03TAG\x10\x05\x12\x0b\n\x07MENTION\x10\x06\x12\x0b\n\x07\x43OMMENT\x10\x07\x12\t\n\x05LOGIN\x10\x62\x12\n\n\x06LOGOUT\x10\x63\x12\t\n\x05\x42LOCK\x10\x64\x12\x0e\n\nCHANGE_BIO\x10\x65\x12\x17\n\x13\x43HANGE_DISPLAY_NAME\x10\x66\x12\x13\n\x0f\x43HANGE_USERNAME\x10g\x12\x13\n\x0fPRIVATE_ACCOUNT\x10n\x12\x12\n\x0ePUBLIC_ACCOUNT\x10o2\xcd\x01\n\x0eHistoryService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12V\n\rGetActivities\x12$.social.history.GetActivitiesRequest\x1a\x1f.social.history.ActListResponse\x12\x30\n\x03Log\x12\x13.social.history.Act\x1a\x14.social.common.Emptyb\x06proto3')

_ACTTYPES = DESCRIPTOR.enum_types_by_name['ActTypes']
ActTypes = enum_type_wrapper.EnumTypeWrapper(_ACTTYPES)
_ACTVERBS = DESCRIPTOR.enum_types_by_name['ActVerbs']
ActVerbs = enum_type_wrapper.EnumTypeWrapper(_ACTVERBS)
ACCOUNT = 0
POST = 1
STORY = 2
DISCUSSION = 3
HASHTAG = 4
LIKE = 0
UNLIKE = 1
FOLLOW = 2
UNFOLLOW = 3
FOLLOW_REQUEST = 4
TAG = 5
MENTION = 6
COMMENT = 7
LOGIN = 98
LOGOUT = 99
BLOCK = 100
CHANGE_BIO = 101
CHANGE_DISPLAY_NAME = 102
CHANGE_USERNAME = 103
PRIVATE_ACCOUNT = 110
PUBLIC_ACCOUNT = 111


_ACT = DESCRIPTOR.message_types_by_name['Act']
_GETACTIVITIESREQUEST = DESCRIPTOR.message_types_by_name['GetActivitiesRequest']
_ACTLISTRESPONSE = DESCRIPTOR.message_types_by_name['ActListResponse']
Act = _reflection.GeneratedProtocolMessageType('Act', (_message.Message,), {
  'DESCRIPTOR' : _ACT,
  '__module__' : 'services.history.history_pb2'
  # @@protoc_insertion_point(class_scope:social.history.Act)
  })
_sym_db.RegisterMessage(Act)

GetActivitiesRequest = _reflection.GeneratedProtocolMessageType('GetActivitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVITIESREQUEST,
  '__module__' : 'services.history.history_pb2'
  # @@protoc_insertion_point(class_scope:social.history.GetActivitiesRequest)
  })
_sym_db.RegisterMessage(GetActivitiesRequest)

ActListResponse = _reflection.GeneratedProtocolMessageType('ActListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTLISTRESPONSE,
  '__module__' : 'services.history.history_pb2'
  # @@protoc_insertion_point(class_scope:social.history.ActListResponse)
  })
_sym_db.RegisterMessage(ActListResponse)

_HISTORYSERVICE = DESCRIPTOR.services_by_name['HistoryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTTYPES._serialized_start=402
  _ACTTYPES._serialized_end=475
  _ACTVERBS._serialized_start=478
  _ACTVERBS._serialized_end=728
  _ACT._serialized_start=113
  _ACT._serialized_end=290
  _GETACTIVITIESREQUEST._serialized_start=292
  _GETACTIVITIESREQUEST._serialized_end=345
  _ACTLISTRESPONSE._serialized_start=347
  _ACTLISTRESPONSE._serialized_end=400
  _HISTORYSERVICE._serialized_start=731
  _HISTORYSERVICE._serialized_end=936
# @@protoc_insertion_point(module_scope)



import copy
import re
from functools import cached_property

from google.protobuf.json_format import ParseDict, MessageToDict  # noqa
from google.protobuf.message import Message  # noqa

from mgo_serializer.exceptions import ValidationError
from mgo_serializer.fields import BaseField, Empty, set_value
from mgo_serializer.helpers import BindingDict, ReturnList, ReturnDict, NestedBoundField, BoundField
from mgo_serializer.meta import SerializerMetaclass


def mongo_to_protobuf(data, schema):
    """
    Convert data to protobuf.
    :return: protobuf
    :rtype: object
    """
    protobuf = schema() if callable(schema) else schema
    return ParseDict(data, protobuf)


def dict_to_lower_case_keys(d):
    to_dict = {}
    for key, value in d.items():
        parse = re.findall(r'[A-Z]?[a-z]+', key)
        key = '_'.join([item.lower() for item in parse])
        to_dict[key] = value
    return to_dict


def proto_to_dict(data):
    data = MessageToDict(data)
    for key, value in data.items():
        if isinstance(value, dict):
            data[key] = dict_to_lower_case_keys(value)

    return data


class BaseSerializer(BaseField):
    """
    Base class for all serializers.
    """

    def __init__(self, instance=None, data=Empty, **kwargs):
        self.instance = instance

        if isinstance(self.instance, Message):
            self.instance = proto_to_dict(self.instance)
        elif isinstance(self.instance, list) and any(isinstance(item, Message) for item in self.instance):
            self.instance = [proto_to_dict(item) for item in self.instance]

        if data is not Empty:
            if isinstance(data, list) and any(isinstance(item, Message) for item in data):
                self.initial_data = [proto_to_dict(item) for item in data]
            elif isinstance(data, list) and not any(isinstance(item, Message) for item in data):
                self.initial_data = data
            elif isinstance(data, Message):
                self.initial_data = proto_to_dict(data)
            else:
                self.initial_data = data

        self.partial = kwargs.pop("partial", False)
        kwargs.pop("many", None)
        super().__init__(**kwargs)

    def __new__(cls, *args, **kwargs):
        if kwargs.pop("many", False):
            return cls.many_init(*args, **kwargs)
        return super().__new__(cls, *args, **kwargs)

    def __class_getitem__(cls, *args, **kwargs):
        """
        Allow type checkers to make serializers generic.
        """
        return cls

    @classmethod
    def many_init(cls, *args, **kwargs):
        child_serializer = cls(*args, **kwargs)
        list_kwargs = {
            'child': child_serializer
        }
        list_kwargs.update({
            key: value for key, value in kwargs.items()
        })
        meta = getattr(cls, 'Meta', None)
        list_serializer_class = getattr(meta, 'list_serializer_class', ListSerializer)
        return list_serializer_class(*args, **list_kwargs)

    def to_internal_value(self, data):
        raise NotImplementedError('.to_internal_value() must be implemented.')

    def to_representation(self, value):
        raise NotImplementedError('.to_representation() must be implemented.')

    def to_protobuf(self, data):
        raise NotImplementedError('.to_protobuf() must be implemented.')

    def create(self, validated_data):
        raise NotImplementedError('.create() must be implemented.')

    def update(self, instance, validated_data):
        raise NotImplementedError('.update() must be implemented.')

    def save(self, **kwargs):
        assert hasattr(self, '_errors'), (
            'You must call `.is_valid()` before calling `.save()`.'
        )

        assert not self.errors, (
            'You cannot call `.save()` on a serializer with invalid data.'
        )

        validated_data = {**self.validated_data, **kwargs}

        primary_keys = [
            field.field_name for field in self.fields.values()
            if field.primary_key and validated_data[field.field_name] is not None
        ]

        # check if primary key is provided
        if not primary_keys:
            self.instance = self.create(validated_data)
        else:
            primary_key_values = {key: validated_data[key] for key in primary_keys}
            self.instance = self.update(primary_key_values, validated_data)

        return self.instance

    def is_valid(self, raise_exception=False):
        """
        Validates the data.
        """
        if not hasattr(self, '_validated_data'):
            try:
                self._validated_data = self.to_internal_value(self.initial_data)
            except ValidationError as exc:
                self._validated_data = {}
                self._errors = exc.detail
            else:
                self._errors = {}

        if self._errors and raise_exception:
            raise ValidationError(self._errors)

        return not bool(self._errors)

    @property
    def data(self):
        """
        Returns the serialized data on the serializer.

        :see: https://www.django-rest-framework.org/api-guide/serializers/#data
        """
        if hasattr(self, 'initial_data') and not hasattr(self, '_validated_data'):
            msg = (
                'When a serializer is passed a `data` keyword argument you '
                'must call `.is_valid()` before attempting to access the '
                'serialized `.data` or `.protobuf` representation.\n'
                'You should either call `.is_valid()` first, '
                'or access `.initial_data` instead.'
            )
            raise AssertionError(msg)

        if not hasattr(self, '_data'):
            if self.instance is not None and not getattr(self, '_errors', None):
                self._data = self.to_representation(
                    self.to_internal_value(self.instance)
                )
            elif hasattr(self, '_validated_data') and not getattr(self, '_errors', None):
                self._data = self.to_representation(self.validated_data)
            else:
                self._data = self.get_initial()

        return self._data

    @property
    def protobuf(self):
        """
        Returns the serialized data on the serializer as protobuf message.

        :return: Return list of protobuf messages
        :rtype: list
        """

        if hasattr(self, 'child') and not self.child.pb:
            raise AttributeError(
                'Protobuf is not defined in {!r} serializer. '
                'You can define it in MetaClass with `schema` key.'.format(self.child.__class__.__name__)
            )

        protobuf_list = []
        self._protobuf = self.data
        if isinstance(self._protobuf, list):
            for item in self._protobuf:
                protobuf_list.append(self.to_protobuf(item))
        else:
            return self.to_protobuf(self._protobuf)
        return protobuf_list

    @property
    def errors(self):
        if not hasattr(self, '_errors'):
            msg = 'You must call `.is_valid()` before accessing `.errors`.'
            raise AssertionError(msg)
        return self._errors

    @property
    def validated_data(self):
        if hasattr(self, 'initial_data') and not hasattr(self, '_validated_data'):
            msg = 'You must call `.is_valid()` before accessing `.validated_data`.'
            raise AssertionError(msg)
        return self._validated_data


class ListSerializer(BaseSerializer):
    """
    Serializer for list of objects.
    """

    child = None
    many = True

    def __init__(self, *args, **kwargs):
        self.child = kwargs.pop('child', copy.deepcopy(self.child))
        super().__init__(*args, **kwargs)
        # Bind child to self.
        self.child.bind(field_name='', parent=self)

    def get_initial(self):
        if hasattr(self, 'initial_data'):
            return self.to_representation(self.initial_data)
        return []

    def to_internal_value(self, data):
        ret = []
        errors = []
        for item in data:
            try:
                validated = self.child.run_validation(item)
            except ValidationError as exc:
                errors.append(exc.detail)
            else:
                ret.append(validated)
                errors.append({})

        if any(errors):
            raise ValidationError(errors)

        return ret

    def to_representation(self, data):
        return [self.child.to_representation(item) for item in data]

    def to_protobuf(self, data):
        return self.child.to_protobuf(
            self.child.to_representation(data)
        )

    def create(self, validated_data):
        return [self.child.create(data) for data in validated_data]

    @staticmethod
    def validate(attrs):
        return attrs

    def run_validation(self, data=Empty):
        """
        We override the default `run_validation`, making it transparent to the user.
        """
        (is_empty_value, data) = self.validate_empty_values(data)
        if is_empty_value:
            return data

        value = self.to_internal_value(data)
        try:
            value = self.validate(value)
            assert value is not None, '.validate() should return the validated data'
        except ValidationError:
            raise ValidationError(detail='_')

        return value

    def is_valid(self, raise_exception=False):
        """
        This implementation is the same as the default, but we use lists as default data instead of dicts.
        """
        if not hasattr(self, '_validated_data'):
            try:
                self._validated_data = self.run_validation(self.initial_data)
            except ValidationError as exc:
                self._validated_data = []
                self._errors = exc.detail
            else:
                self._errors = []

        if self._errors and raise_exception:
            raise ValidationError(self._errors)

        return not bool(self._errors)

    @property
    def data(self):
        ret = super().data
        return ReturnList(ret, serializer=self)

    @property
    def errors(self):
        ret = super().errors
        if isinstance(ret, dict):
            return ReturnDict(ret, serializer=self)
        return ReturnList(ret, serializer=self)

    @property
    def protobuf(self):
        ret = super().protobuf
        return ReturnList(ret, serializer=self)


class Serializer(BaseSerializer, metaclass=SerializerMetaclass):

    @cached_property
    def fields(self):
        fields = BindingDict(self)
        for key, value in self.get_fields().items():
            fields[key] = value
        return fields

    @property
    def _readable_fields(self):
        for field in self.fields.values():
            yield field

    def get_fields(self):
        """
        Returns a dictionary of {field_name: field_instance}.
        """
        return copy.deepcopy(self._declared_fields)

    def get_initial(self):
        if hasattr(self, 'initial_data'):
            return dict([
                (field_name, field.get_value(self.initial_data, self))
                for field_name, field in self.fields.items()
                if (field.get_value(self.initial_data, self) is not Empty)
            ])

        return dict([
            (field.field_name, field.get_initial())
            for field in self.fields.values()
        ])

    def to_internal_value(self, data):
        ret = dict()
        errors = dict()
        fields = self._readable_fields

        for field in fields:
            validate_method = getattr(self, 'validate_' + field.field_name, None)
            primitive_value = field.get_value(data, self)
            try:
                validated_value = field.run_validation(primitive_value)
                if validate_method:
                    validated_value = validate_method(primitive_value)
            except ValidationError as e:
                errors[field.field_name] = e.detail
            else:
                set_value(ret, field.attributes, validated_value)

        if errors:
            raise ValidationError(errors)

        return ret

    def to_representation(self, instance):
        ret = {}
        fields = self._readable_fields
        for field in fields:
            if field.db_only:
                continue
            attribute = field.get_attribute(instance)
            key = field.proto_field if field.proto_field else field.field_name
            if attribute is None:
                ret[key] = None
            else:
                ret[key] = field.to_representation(attribute)
        return ret

    def to_protobuf(self, data):
        if self.pb:
            return mongo_to_protobuf(data, self.pb)
        return self.pb

    def __iter__(self):
        for field in self.fields.values():
            yield field

    def __getitem__(self, key):
        field = self.fields[key]
        value = self.data.get(key)
        error = self.errors.get(key) if hasattr(self, '_errors') else None
        if isinstance(field, Serializer):
            return NestedBoundField(field, value, error)
        return BoundField(field, value, error)

    def create(self, validated_data):
        model_class = self.meta.model
        return model_class.objects.create(**validated_data)

    def update(self, instance, validated_data):
        model = self.meta.model.objects.get(id=instance['id'])
        model.update(**validated_data)
        return model

    @property
    def data(self):
        ret = super().data
        return ReturnDict(ret, serializer=self)

    @property
    def errors(self):
        ret = super().errors
        return ReturnDict(ret, serializer=self)
